import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:intl/intl.dart';
import 'package:provider/provider.dart';
import 'package:retgoo_sdk/models/directform.dart';
import 'package:retgoo_sdk/providers/process_provider.dart';

class ProcessInformationPage extends StatelessWidget {
  ProcessInformationPage({Key key}) : super(key: key);

  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("Process Information"),
      ),
      body: SizedBox.expand(
        child: Selector<ProcessProvider, DirectForm>(
          selector: (context, provider) => provider.directForm,
          builder: (context, directForm, child) {
            return buildData(directForm);
          },
        ),
      ),
    );
  }

  buildData(DirectForm directForm) {
    return SingleChildScrollView(
      padding: const EdgeInsets.all(16.0),
      physics: AlwaysScrollableScrollPhysics(),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.stretch,
        children: [
          buildSection("Proses Bisnis"),
          KeyValues(
            data: {
              "Name": directForm.masterProcessName,
              "Version": directForm.processName,
            },
          ),
          Divider(),
          buildSection("Eksekusi"),
          KeyValues(
            data: {
              "ID Proses": directForm.idProcessInstance,
              "Dibuat oleh": directForm.createdBy?.name ?? "Undefined",
              "Pada": DateFormat("EEEE, dd MMMM yyyy HH:mm")
                  .format(directForm?.createdAt?.toLocal()),
              "Batas waktu": "Tidak terbatas",
              "Last Action": "none",
              "Status": "Ready",
            },
          ),
          Divider(),
          buildSection("Tantangan"),
          KeyValues(
            data: {
              "Goal": directForm.businessInfo.businessGoal ?? "undefined",
              "Pemilik": directForm.businessInfo.owner ?? "undefined",
              "Partisipan": directForm.businessInfo.owner ?? "undefined",
              "Durasi": directForm.businessInfo.owner ?? "undefined",
            },
          ),
          Divider(),
          buildSection("Nilai"),
          KeyValues(data: {
            "Shareholder": directForm.businessInfo.businessValue.shareholder,
            "Customer": directForm.businessInfo.businessValue.customer,
            "Managerial": directForm.businessInfo.businessValue.managerial,
            "Partner": directForm.businessInfo.businessValue.partner,
            "Employee": directForm.businessInfo.businessValue.employee,
            "Social": directForm.businessInfo.businessValue.social,
          }),
        ],
      ),
    );
  }

  buildSection(String caption) {
    return Padding(
      padding: const EdgeInsets.symmetric(vertical: 8.0),
      child: Row(
        children: [
          Icon(CupertinoIcons.pin_fill),
          const SizedBox(
            width: 8.0,
          ),
          Expanded(
            child: Text(
              caption,
              style: TextStyle(
                fontSize: 20.0,
                fontWeight: FontWeight.bold,
              ),
            ),
          ),
        ],
      ),
    );
  }
}

class KeyValues extends StatelessWidget {
  final Map<String, dynamic> data;
  const KeyValues({Key key, @required this.data}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Table(
      columnWidths: {
        0: FixedColumnWidth(120),
        1: FixedColumnWidth(8.0),
      },
      children: [
        for (var key in data.keys)
          TableRow(
            children: [
              Text(
                key,
                style: TextStyle(
                  fontSize: 16.0,
                  fontWeight: FontWeight.w300,
                ),
              ),
              Text(
                ":",
                style: TextStyle(
                  fontSize: 16.0,
                  fontWeight: FontWeight.w300,
                ),
              ),
              Text(
                data[key].toString(),
                style: TextStyle(
                  fontSize: 16.0,
                ),
              ),
            ],
          ),
      ],
    );
  }
}
